@@ -14,4 +14,6 @@ from cacab.plot.main import \
     heatmap_3d, \
     fill_between_gradient, \
     annotated_axline, \
-    PointSelector
+    PointSelector, \
+    freeze_axes, \
+    setup_orsted
