@@ -507,6 +507,19 @@ class PointSelector:
         #     self.collections[i].set_facecolors(self.fcs[i])
         self.canvas.draw_idle()
 
+def freeze_axes(ax):
+    xlim_base = ax.get_xlim()
+    ylim_base = ax.get_ylim()
+    ax.callbacks.connect("xlim_changed", lambda _, ax_i=ax, xlim_i=xlim_base: ax_i.set_xlim(xlim_i) if ax_i.get_xlim() != xlim_i else None)
+    ax.callbacks.connect("ylim_changed", lambda _, ax_j=ax, ylim_j=ylim_base: ax_j.set_ylim(ylim_j) if ax_j.get_xlim() != ylim_j else None)
+
+def setup_orsted():
+    matplotlib.use("Qt5Agg")
+    matplotlib.pyplot.style.use({
+        "grid.alpha": 0.5,
+        "axes.grid": True,
+        "axes.prop_cycle": matplotlib.cycler(color=orsted_colors),
+    })
 
 
 if __name__ == '__main__':
